<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="214"/>
        <source>Drop Error</source>
        <translation>拖放错误</translation>
    </message>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="215"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>文件/URL &apos;%1&apos; 暂时无法被嵌入到快速启动</translation>
    </message>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="321"/>
        <source>Drop application
icons here</source>
        <translation>移动应用程序图标至此</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="55"/>
        <source>Move left</source>
        <translation>左移</translation>
    </message>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="58"/>
        <source>Move right</source>
        <translation>右移</translation>
    </message>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="62"/>
        <source>Remove from quicklaunch</source>
        <translation>从快速启动删除</translation>
    </message>
</context>
</TS>
